.. _api ref:

=============
API Reference
=============

The full API documentation for all classes and functions in the **WFacer** package are
listed below.

.. toctree::
   :maxdepth: 2

   sample_generators/index
   species_decorators/index
   utils/index
   WFacer/index

Autogenerated Indices
---------------------

* :ref:`modindex`
* :ref:`genindex`
* :ref:`search`
